summaryrefslogtreecommitdiffstats
path: root/konqueror/keditbookmarks/commands.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'konqueror/keditbookmarks/commands.cpp')
-rw-r--r--konqueror/keditbookmarks/commands.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/konqueror/keditbookmarks/commands.cpp b/konqueror/keditbookmarks/commands.cpp
index c7c5f83a6..f0855fec0 100644
--- a/konqueror/keditbookmarks/commands.cpp
+++ b/konqueror/keditbookmarks/commands.cpp
@@ -643,13 +643,13 @@ KEBMacroCommand* CmdGen::insertMimeSource(
bool modified = false;
const char *format = 0;
for (int i = 0; format = data->format(i), format; i++) {
// qt docs don't say if tqencodedData(blah) where
// blah is not a stored mimetype should return null
// or not. so, we search. sucky...
if (strcmp(format, "GALEON_BOOKMARK") == 0) {
modified = true;
TQStoredDrag *mydrag = new TQStoredDrag("application/x-xbel");
- mydrag->setEncodedData(data->tqencodedData("GALEON_BOOKMARK"));
+ mydrag->setEncodedData(data->encodedData("GALEON_BOOKMARK"));
data = mydrag;
break;
} else if( strcmp(format, "application/x-xbel" )==0) {
@@ -643,13 +643,13 @@ KEBMacroCommand* CmdGen::insertMimeSource(
const char *format = 0;
for (int i = 0; format = data->format(i), format; i++) {
- // qt docs don't say if tqencodedData(blah) where
+ // qt docs don't say if encodedData(blah) where
// blah is not a stored mimetype should return null
// or not. so, we search. sucky...